pub enum FoldBody {
Node(String),
Subgraph(Box<Graph>),
}Expand description
Variants
Node(String)
Run each pass through an existing node in this document, by id.
Subgraph(Box<Graph>)
Run each pass through an embedded sub-graph. Boxed because a Graph
contains nodes, one of which may itself be a fold, so the type is
recursive.